==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/FormalAttributeValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttributeValue;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.InstanceAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InstanceAttributeValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class FormalAttributeValueSetImpl extends InstanceSet<FormalAttributeValueSet,FormalAttributeValue> implements FormalAttributeValueSet {

    // attributes
    @Override
    public void setAv_ID( UniqueId ref_Av_ID ) throws XtumlException {
        for ( FormalAttributeValue formalattributevalue : this ) formalattributevalue.setAv_ID( ref_Av_ID );
    }


    // selections
    @Override
    public InstanceAttributeValueSet R948_is_a_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( FormalAttributeValue formalattributevalue : this ) instanceattributevalueset.add( formalattributevalue.R948_is_a_InstanceAttributeValue() );
        return instanceattributevalueset;
    }


    @Override
    public FormalAttributeValue nullElement() {
        return FormalAttributeValueImpl.EMPTY_FORMALATTRIBUTEVALUE;
    }

    @Override
    public FormalAttributeValueSet emptySet() {
      return new FormalAttributeValueSetImpl();
    }

    @Override
    public FormalAttributeValueSet value() {
        return this;
    }

    @Override
    public List<FormalAttributeValue> elements() {
        return Arrays.asList(toArray(new FormalAttributeValue[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/FormalAttributeValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttributeValue;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.InstanceAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InstanceAttributeValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FormalAttributeValueSetImpl extends InstanceSet<FormalAttributeValueSet,FormalAttributeValue> implements FormalAttributeValueSet {

    public FormalAttributeValueSetImpl() {
    }

    public FormalAttributeValueSetImpl(Comparator<? super FormalAttributeValue> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAv_ID( UniqueId ref_Av_ID ) throws XtumlException {
        for ( FormalAttributeValue formalattributevalue : this ) formalattributevalue.setAv_ID( ref_Av_ID );
    }


    // selections
    @Override
    public InstanceAttributeValueSet R948_is_a_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( FormalAttributeValue formalattributevalue : this ) instanceattributevalueset.add( formalattributevalue.R948_is_a_InstanceAttributeValue() );
        return instanceattributevalueset;
    }


    @Override
    public FormalAttributeValue nullElement() {
        return FormalAttributeValueImpl.EMPTY_FORMALATTRIBUTEVALUE;
    }

    @Override
    public FormalAttributeValueSet emptySet() {
      return new FormalAttributeValueSetImpl();
    }

    @Override
    public FormalAttributeValueSet emptySet(Comparator<? super FormalAttributeValue> comp) {
      return new FormalAttributeValueSetImpl(comp);
    }

    @Override
    public FormalAttributeValueSet value() {
        return this;
    }

    @Override
    public List<FormalAttributeValue> elements() {
        return Arrays.asList(toArray(new FormalAttributeValue[0]));
    }

}
